import unittest
import base64
import requests



url = 'http://192.168.199.107:18080'


def send_request(image_path, image_type):
    with open(image_path, 'rb') as f:
        img_str: str = base64.encodebytes(f.read()).decode('utf-8')
        r = requests.post(f'{url}/ocr_system/idcard', json={'image': img_str, 'image_type': image_type})
        print(r.json())
        return r.json()


class TestIdCardAddress(unittest.TestCase):
    def test_01(self):
        image_path = '../images/ture/01.jpg'
        r = send_request(image_path, '0')
        self.assertEqual(r['status'], '000', 'status case error')
        self.assertEqual(r['result']['orientation'], 0, 'orientation case error')
        self.assertEqual(r['result']['name']['text'], '宋宝磊', 'name case error')
        self.assertEqual(r['result']['id']['text'], '150430199905051616', 'id case error')
        self.assertEqual(r['result']['ethnicity']['text'], '汉', 'ethnicity case error')
        self.assertEqual(r['result']['gender']['text'], '男', 'gender case error')
        self.assertEqual(r['result']['birthday']['text'], '1999年05月05日', 'birthday case error')
        self.assertEqual(r['result']['address']['text'], '内蒙古赤峰市敖汉旗四家子镇林家地村唐坊沟七组', 'address case error')

    def test_02(self):
        image_path = '../images/ture/02.jpg'
        r = send_request(image_path, '0')
        self.assertEqual(r['status'], '000', 'status case error')
        self.assertEqual(r['result']['orientation'], 2, 'orientation case error')
        self.assertEqual(r['result']['name']['text'], '方势文', 'name case error')
        self.assertEqual(r['result']['id']['text'], '360428199610220096', 'id case error')
        self.assertEqual(r['result']['ethnicity']['text'], '汉', 'ethnicity case error')
        self.assertEqual(r['result']['gender']['text'], '男', 'gender case error')
        self.assertEqual(r['result']['birthday']['text'], '1996年10月22日', 'birthday case error')
        self.assertEqual(r['result']['address']['text'], '江西省九江市都昌县都昌镇沿湖路238号', 'address case error')

    def test_03(self):
        image_path = '../images/ture/03.jpg'
        r = send_request(image_path, '0')
        self.assertEqual(r['status'], '000', 'status case error')
        self.assertEqual(r['result']['orientation'], 0, 'orientation case error')
        self.assertEqual(r['result']['name']['text'], '彭贤端', 'name case error')
        self.assertEqual(r['result']['id']['text'], '450922199412083669', 'id case error')
        self.assertEqual(r['result']['ethnicity']['text'], '汉', 'ethnicity case error')
        self.assertEqual(r['result']['gender']['text'], '女', 'gender case error')
        self.assertEqual(r['result']['birthday']['text'], '1994年12月08日', 'birthday case error')
        self.assertEqual(r['result']['address']['text'], '广西陆川县清湖镇塘寨村新屋队62号', 'address case error')

    def test_04(self):
        image_path = '../images/ture/04.png'
        r = send_request(image_path, '0')
        self.assertEqual(r['status'], '000', 'status case error')
        self.assertEqual(r['result']['orientation'], 0, 'orientation case error')
        self.assertEqual(r['result']['name']['text'], '王晓凤', 'name case error')
        self.assertEqual(r['result']['id']['text'], '150921199910021527', 'id case error')
        self.assertEqual(r['result']['ethnicity']['text'], '汉', 'ethnicity case error')
        self.assertEqual(r['result']['gender']['text'], '女', 'gender case error')
        self.assertEqual(r['result']['birthday']['text'], '1999年10月02日', 'birthday case error')
        self.assertEqual(r['result']['address']['text'], '呼和浩特市新城区赛马场北路城市维也纳13号楼2单元1303号', 'address case error')

    def test_05(self):
        image_path = '../images/ture/05.jpg'
        r = send_request(image_path, '0')
        self.assertEqual(r['status'], '000', 'status case error')
        self.assertEqual(r['result']['orientation'], 0, 'orientation case error')
        self.assertEqual(r['result']['name']['text'], '任学东', 'name case error')
        self.assertEqual(r['result']['id']['text'], '152630198501117517', 'id case error')
        self.assertEqual(r['result']['ethnicity']['text'], '汉', 'ethnicity case error')
        self.assertEqual(r['result']['gender']['text'], '男', 'gender case error')
        self.assertEqual(r['result']['birthday']['text'], '1985年01月11日', 'birthday case error')
        self.assertEqual(r['result']['address']['text'], '内蒙古乌兰察布市察哈尔右翼前旗巴音塔拉镇谢家村22户', 'address case error')

    def test_06(self):
        image_path = '../images/ture/06.jpg'
        r = send_request(image_path, '0')
        self.assertEqual(r['status'], '000', 'status case error')
        self.assertEqual(r['result']['orientation'], 0, 'orientation case error')
        self.assertEqual(r['result']['name']['text'], '田浩', 'name case error')
        self.assertEqual(r['result']['id']['text'], '640221199702060618', 'id case error')
        self.assertEqual(r['result']['ethnicity']['text'], '汉', 'ethnicity case error')
        self.assertEqual(r['result']['gender']['text'], '男', 'gender case error')
        self.assertEqual(r['result']['birthday']['text'], '1997年02月06日', 'birthday case error')
        self.assertEqual(r['result']['address']['text'], '宁夏平罗县黄渠桥镇侯家梁村二队29', 'address case error')

    def test_07_0(self):
        image_path = '../images/ture/07_0.jpg'
        r = send_request(image_path, '0')
        self.assertEqual(r['status'], '000', 'status case error')
        self.assertEqual(r['result']['orientation'], 0, 'orientation case error')
        self.assertEqual(r['result']['name']['text'], '左翔宇', 'name case error')
        self.assertEqual(r['result']['id']['text'], '220204199910123017', 'id case error')
        self.assertEqual(r['result']['ethnicity']['text'], '蒙古', 'ethnicity case error')
        self.assertEqual(r['result']['gender']['text'], '男', 'gender case error')
        self.assertEqual(r['result']['birthday']['text'], '1999年10月12日', 'birthday case error')
        self.assertEqual(r['result']['address']['text'], '吉林省吉林市船营区鑫安小区2-6-60号', 'address case error')

    def test_07_90(self):
        image_path = '../images/ture/07_90.jpg'
        r = send_request(image_path, '0')
        self.assertEqual(r['status'], '000', 'status case error')
        self.assertEqual(r['result']['orientation'], 1, 'orientation case error')
        self.assertEqual(r['result']['name']['text'], '左翔宇', 'name case error')
        self.assertEqual(r['result']['id']['text'], '220204199910123017', 'id case error')
        self.assertEqual(r['result']['ethnicity']['text'], '蒙古', 'ethnicity case error')
        self.assertEqual(r['result']['gender']['text'], '男', 'gender case error')
        self.assertEqual(r['result']['birthday']['text'], '1999年10月12日', 'birthday case error')
        self.assertEqual(r['result']['address']['text'], '吉林省吉林市船营区鑫安小区2-6-60号', 'address case error')

    def test_07_180(self):
        image_path = '../images/ture/07_180.jpg'
        r = send_request(image_path, '0')
        self.assertEqual(r['status'], '000', 'status case error')
        self.assertEqual(r['result']['orientation'], 2, 'orientation case error')
        self.assertEqual(r['result']['name']['text'], '左翔宇', 'name case error')
        self.assertEqual(r['result']['id']['text'], '220204199910123017', 'id case error')
        self.assertEqual(r['result']['ethnicity']['text'], '蒙古', 'ethnicity case error')
        self.assertEqual(r['result']['gender']['text'], '男', 'gender case error')
        self.assertEqual(r['result']['birthday']['text'], '1999年10月12日', 'birthday case error')
        self.assertEqual(r['result']['address']['text'], '吉林省吉林市船营区鑫安小区2-6-60号', 'address case error')

    def test_08_0(self):
        image_path = '../images/ture/08_0.jpg'
        r = send_request(image_path, '0')
        self.assertEqual(r['status'], '000', 'status case error')
        self.assertEqual(r['result']['orientation'], 0, 'orientation case error')
        self.assertEqual(r['result']['name']['text'], '张开天', 'name case error')
        self.assertEqual(r['result']['id']['text'], '622301199710247376', 'id case error')
        self.assertEqual(r['result']['ethnicity']['text'], '汉', 'ethnicity case error')
        self.assertEqual(r['result']['gender']['text'], '男', 'gender case error')
        self.assertEqual(r['result']['birthday']['text'], '1997年10月24日', 'birthday case error')
        self.assertEqual(r['result']['address']['text'], '甘肃省武威市凉州区九墩乡平乐村四组23号', 'address case error')

    def test_08_180(self):
        image_path = '../images/ture/08_180.jpg'
        r = send_request(image_path, '0')
        self.assertEqual(r['status'], '000', 'status case error')
        self.assertEqual(r['result']['orientation'], 2, 'orientation case error')
        self.assertEqual(r['result']['name']['text'], '张开天', 'name case error')
        self.assertEqual(r['result']['id']['text'], '622301199710247376', 'id case error')
        self.assertEqual(r['result']['ethnicity']['text'], '汉', 'ethnicity case error')
        self.assertEqual(r['result']['gender']['text'], '男', 'gender case error')
        self.assertEqual(r['result']['birthday']['text'], '1997年10月24日', 'birthday case error')
        self.assertEqual(r['result']['address']['text'], '甘肃省武威市凉州区九墩乡平乐村四组23号', 'address case error')

    def test_09(self):
        image_path = '../images/ture/09.jpeg'
        r = send_request(image_path, '0')
        self.assertEqual(r['status'], '000', 'status case error')
        self.assertEqual(r['result']['orientation'], 0, 'orientation case error')
        self.assertEqual(r['result']['name']['text'], '韩毅', 'name case error')
        self.assertEqual(r['result']['id']['text'], '211102199912162010', 'id case error')
        self.assertEqual(r['result']['ethnicity']['text'], '汉', 'ethnicity case error')
        self.assertEqual(r['result']['gender']['text'], '男', 'gender case error')
        self.assertEqual(r['result']['birthday']['text'], '1999年12月16日', 'birthday case error')
        self.assertEqual(r['result']['address']['text'], '辽宁省盘锦市双台子区胜利街道团结社区15区40号', 'address case error')

    def test_10(self):
        image_path = '../images/ture/10.jpg'
        r = send_request(image_path, '0')
        self.assertEqual(r['status'], '000', 'status case error')
        self.assertEqual(r['result']['orientation'], 0, 'orientation case error')
        self.assertEqual(r['result']['name']['text'], '曾令权', 'name case error')
        self.assertEqual(r['result']['id']['text'], '432524199306221414', 'id case error')
        self.assertEqual(r['result']['ethnicity']['text'], '汉', 'ethnicity case error')
        self.assertEqual(r['result']['gender']['text'], '男', 'gender case error')
        self.assertEqual(r['result']['birthday']['text'], '1993年06月22日', 'birthday case error')
        self.assertEqual(r['result']['address']['text'], '湖南省新化县维山乡官庄村陈家冲组21号', 'address case error')


if __name__ == '__main__':
    unittest.main()
